#!/bin/sh

flags=`cat /proc/cpuinfo | grep "^flags" | uniq`

has_sse2=`echo $flags | grep "sse2"`
has_sse4a=`echo $flags | grep "sse4a"`
has_sse41=`echo $flags | grep "sse4_1"`
has_sse42=`echo $flags | grep "sse4_2"`
has_avx=`echo $flags | grep "avx "`
has_avx2=`echo $flags | grep "avx2"`
has_popcnt=`echo $flags | grep "popcnt"`
architecture=`getconf LONG_BIT`

asm_config_file="asm_config.inc"
cpp_config_file="cpp_config.h"
make_config_file="config.make"

rm -rf $asm_config_file
rm -rf $cpp_config_file
rm -rf $make_config_file

echo "#ifndef CONFIG_H" >>$cpp_config_file
echo "#define CONFIG_H" >>$cpp_config_file

make_options=""

if test "$architecture" = "32" ; then
	echo "#define ARCHITECTURE_32_BITS" >>$cpp_config_file
	echo "%define ARCHITECTURE 32" >>$asm_config_file
	echo "CFG_NFLAGS=-f elf" >>$make_config_file
fi
if test "$architecture" = "64" ; then
	echo "#define ARCHITECTURE_64_BITS" >>$cpp_config_file
	echo "%define ARCHITECTURE 64" >>$asm_config_file
	echo "CFG_NFLAGS=-f elf64" >>$make_config_file
fi

if test -n "$has_sse2" ; then
	echo "#define HAS_SSE2" >>$cpp_config_file
	echo "%define HAS_SSE2" >>$asm_config_file
	make_options="-msse2"
fi

if test -n "$has_sse4a" ; then
	echo "#define HAS_SSE4A" >>$cpp_config_file
	echo "%define HAS_SSE4A" >>$asm_config_file
	make_options="-msse4a -msse4.2"
fi

if test -n "$has_sse41" ; then
	echo "#define HAS_SSE41" >>$cpp_config_file
	echo "%define HAS_SSE41" >>$asm_config_file
	make_options="-msse4.1"
fi

if test -n "$has_sse42" ; then
	echo "#define HAS_SSE42" >>$cpp_config_file
	echo "%define HAS_SSE42" >>$asm_config_file
	make_options="-msse4.2"
fi

if test -n "$has_avx" ; then
	echo "#define HAS_AVX" >>$cpp_config_file
	echo "%define HAS_AVX" >>$asm_config_file
	make_options="-mavx"
fi

if test -n "$has_avx2" ; then
	echo "#define HAS_AVX2" >>$cpp_config_file
	echo "%define HAS_AVX2" >>$asm_config_file
	make_options="-mavx2"
fi

if test -n "$has_popcnt" ; then
	echo "#define HAS_POPCNT" >>$cpp_config_file
	echo "%define HAS_POPCNT" >>$asm_config_file
	make_options="${make_options} -mpopcnt"
fi

echo "#endif" >>$cpp_config_file

echo "CFG_CFLAGS=${make_options}" >>$make_config_file

