#!/bin/sh
exe="./main.exe"
nbr_methods=`$exe -2 | grep "^number of methods" | cut -d'=' -f2`
k=`expr $nbr_methods - 1`
methods=`seq 0 $k`

if test $# -gt 0 ; then
	methods=`echo $* | sed -r -e "s/[ ]+/ /g"`
	nbr_methods=$#
fi

echo "methods plotted: $methods"
 
sizes=`cat sizes.param.txt`
 
# do not modify script after this line

rm -rf plot*.eps

gnuplot_exe=`which gnuplot`
if test -z "$gnuplot_exe" ; then
	echo "Error: please install gnuplot !"
	exit 1;
fi 

cpu=`cat /proc/cpuinfo | grep "model name" | uniq | cut -d':' -f2`
echo "CPU: $cpu"

# generate gnuplot file
for method in $methods ; 
do
	input="results_method_$method.csv"
	output="results_method_$method.data"
	rm -rf $output
	for size in $sizes ; do
		cat $input | grep -v "^#" | cut -d';' -f2,3 | grep "^ $size ;" | sed -e "s/;/ /g" >>$output
	done
done

# generate gluplot file
output="gnuplot_instructions.gplot"
echo "set title \"cpu: $cpu\" " > $output
echo "set output \"plot.pdf\" " >> $output
echo "set terminal pdfcairo " >> $output
echo "set key below" >> $output
echo "set xlabel \"size (number of characters)\" " >>$output
echo "set ylabel \"time (seconds)\" " >>$output

echo -n "plot " >> $output

method=`echo $methods | cut -d' ' -f1`
method_name=`$exe -2 | grep "^method $method=" | cut -d'=' -f2`
echo -n " \"results_method_$method.data\" using 1:2 with lines title \"$method_name\"" >> $output
i=2
while [ $i -le $nbr_methods ] ; do
	method=`echo $methods | cut -d' ' -f$i`
	method_name=`$exe -2 | grep "^method $method=" | cut -d'=' -f2`
	echo -n ", \"results_method_$method.data\" using 1:2 with lines title \"$method_name\"" >> $output
	i=`expr $i + 1`
done	
echo " " >> $output

# cat gnuplot_instructions.gplot 

gnuplot gnuplot_instructions.gplot
evince plot.pdf 2>/dev/null

proc_name=`cat /proc/cpuinfo | grep "model name" | uniq | cut -d':' -f2 | sed -r -e "s/\(R\)//g" | sed -r -e "s/\(TM\)//g" | sed -r -e "s/ +/_/g"`

# exit 1

for method in $methods ;
do
	cp results_method_$method.csv results/${proc_name}_method_${method}.csv
done

